@@ -13,7 +13,7 @@ class TestDOMNodeFilter (TestCase):
         self.assertEqual(DOM_FILTER_ACCEPT, 1)
         self.assertEqual(DOM_FILTER_REJECT, 2)
         self.assertEqual(DOM_FILTER_SKIP, 3)
-        self.assertEqual(DOM_SHOW_ALL, cast_int(0xFFFFFFFF))
+        self.assertEqual(DOM_SHOW_ALL, cast_uint(0xFFFFFFFF))
         self.assertEqual(DOM_SHOW_ELEMENT, 0x00000001)
         self.assertEqual(DOM_SHOW_ATTRIBUTE, 0x00000002)
         self.assertEqual(DOM_SHOW_TEXT, 0x00000004)
